from setuptools import setup

setup(name='prob_s_dists',
      version='0.2',
      description='Gaussian distribution, Binomial distribution',
      packages=['prob_s_dists'],
      author = 'Saswata Mishra',
      author_email = 'mysaswatamishra@gmail.com',
      zip_safe=False)
